@@ -666,6 +666,11 @@ int print_file(const char *filename, int convert)
                 ret = print_file("<STDIN>", 0);
 
                 wait_for_process(renderer_pid);
+                if (in != NULL)
+                  fclose(in);
+                if (out != NULL)
+                  fclose(out);
+
                 return ret;
             }
 
@@ -683,6 +688,8 @@ int print_file(const char *filename, int convert)
 
         case UNKNOWN_FILE:
 	    _log("Cannot process \"%s\": Unknown filetype.\n", filename);
+	    if (file != NULL)
+	      fclose(file);
 	    return 0;
     }
 
@@ -725,7 +732,7 @@ int main(int argc, char** argv)
     const char* str;
     char *p, *filename;
     const char *path;
-    char tmp[1024], gstoraster[256];
+    char tmp[1024], profile_arg[256], gstoraster[512];
     int havefilter, havegstoraster;
     dstr_t *filelist;
     list_t * arglist;
@@ -811,10 +818,14 @@ int main(int argc, char** argv)
 
     if (getenv("PPD")) {
         strncpy(job->ppdfile, getenv("PPD"), 2048);
+        if (strlen(getenv("PPD")) > 2047)
+          job->ppdfile[2047] = '\0';
         spooler = SPOOLER_CUPS;
-	if (getenv("CUPS_SERVERBIN"))
-	    strncpy(cupsfilterpath, getenv("CUPS_SERVERBIN"),
-		    sizeof(cupsfilterpath));
+    if (getenv("CUPS_SERVERBIN")) {
+        strncpy(cupsfilterpath, getenv("CUPS_SERVERBIN"), sizeof(cupsfilterpath));
+        if (strlen(getenv("CUPS_SERVERBIN")) > PATH_MAX-1)
+          cupsfilterpath[PATH_MAX-1] = '\0';
+        }
     }
 
     /* Check status of printer color management from the color manager */
@@ -834,10 +845,14 @@ int main(int argc, char** argv)
            allow duplicates, and use the last specified one */
             while ((str = arglist_get_value(arglist, "-p"))) {
                 strncpy(job->ppdfile, str, 2048);
+                if (strlen(str) > 2047)
+                  job->ppdfile[2047] = '\0';
                 arglist_remove(arglist, "-p");
             }
 	    while ((str = arglist_get_value(arglist, "--ppd"))) {
 	        strncpy(job->ppdfile, str, 2048);
+	        if (strlen(str) > 2047)
+	          job->ppdfile[2047] = '\0';
 	        arglist_remove(arglist, "--ppd");
 	    }
 
@@ -994,7 +1009,7 @@ int main(int argc, char** argv)
             }
             if (!havegstoraster) {
                 const char **qualifier = NULL;
-                const char *icc_profile = NULL;
+                char *icc_profile = NULL;
 
                 if (!cm_disabled) {
                   qualifier = get_ppd_qualifier();
@@ -1014,12 +1029,13 @@ int main(int argc, char** argv)
                 /* ICC profile is specified for Ghostscript unless
                    "cm-calibration" option was passed in foomatic-rip */
                 if (icc_profile != NULL)
-                  snprintf(cmd, sizeof(cmd),
+                  snprintf(profile_arg, sizeof(profile_arg),
                            "-sOutputICCProfile='%s'", icc_profile);
                 else
-                  cmd[0] = '\0';
+                  profile_arg[0] = '\0';
 
-                snprintf(gstoraster, sizeof(gstoraster), "gs -dQUIET -dDEBUG -dPARANOIDSAFER -dNOPAUSE -dBATCH -dNOINTERPOLATE -dNOMEDIAATTRS -sDEVICE=cups -dShowAcroForm %s -sOutputFile=- -", cmd);
+                snprintf(gstoraster, sizeof(gstoraster), "gs -dQUIET -dDEBUG -dPARANOIDSAFER -dNOPAUSE -dBATCH -dNOINTERPOLATE -dNOMEDIAATTRS -sDEVICE=cups -dShowAcroForm %s -sOutputFile=- -", profile_arg);
+                free(icc_profile);
             }
 
             /* build Ghostscript/CUPS driver command line */
